<?php
/**
 * Plugin Name: WP-CustomGPT
 * Description: A simple WordPress plugin to manage a chatbot ID and include a JavaScript file.
 * Version: 1.0
 * Author: Your Name
 */
include_once plugin_dir_path( __FILE__ ) . 'config.php';

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

class MyChatbotPlugin {
    public function __construct() {
        add_action('admin_menu', array($this, 'add_admin_menu'));
        add_action('admin_init', array($this, 'register_settings'));
        add_action('wp_enqueue_scripts', array($this, 'enqueue_chatbot_script'));
        add_action('save_post', array($this, 'my_custom_save_post'), 10, 3);
        add_action('delete_post', array($this, 'my_custom_delete_post'), 10);
        add_action('trashed_post', array($this, 'my_custom_delete_post'), 10, 1);
        add_action('untrashed_post', array($this, 'my_untrash_post'), 10, 1);


    }

    public function add_admin_menu() {
        add_menu_page(
            'WP-CustomGPT Configuration',       // Page title
            'WP-CustomGPT',            // Menu title
            'manage_options',              // Capability
            'chatbot-settings',            // Menu slug
            array($this, 'create_admin_page'), // Callback function
            'dashicons-admin-comments',    // Icon (optional)
            6                              // Position (optional)
        );
    }

    public function register_settings() {
        register_setting('chatbot-options', 'chatbot_id');
    }

    public function create_admin_page() {
        ?>
        <div class="wrap">
            <h1>WP-CustomGPT Settings</h1>
            <form method="post" action="options.php">
                <?php settings_fields('chatbot-options'); ?>
                <?php do_settings_sections('chatbot-options'); ?>
                <table class="form-table">
                    <tr valign="top">
                    <th scope="row">Chatbot ID</th>
                    <td><input type="text" name="chatbot_id" value="<?php echo esc_attr(get_option('chatbot_id')); ?>" size="39" /></td>
                    </tr>
                </table>
                <?php submit_button(); ?>
            </form>
        </div>
        <?php
    }

    public function enqueue_chatbot_script() {
        $chatbot_id = get_option('chatbot_id');
        if (!empty($chatbot_id)) {
            wp_enqueue_script('my-chatbot-script', 'https://wp-customgpt.com/js/', array(), null, true);
            wp_localize_script('my-chatbot-script', 'chatbotParams', array('chatbot_id' => $chatbot_id));
        }
    }

    public function my_custom_save_post($post_ID, $post, $update) {
        if ($post->post_status != 'publish') {
            return;
        }

        // Prepare the data to send
        $data = array(
            'id' => $post_ID,
            'chatbot_id' => get_option('chatbot_id'),
        );

        // Define the API URL
        $api_url = untrailingslashit(WPGPT_API_BASE_URL) . '/api/post_saved/';
        // Send a POST request to the external API
        $response = wp_remote_post($api_url, array(
            'method' => 'POST',
            'headers' => array(
                'Content-Type' => 'application/json; charset=utf-8',
            ),
            'body' => json_encode($data),
        ));

        if (is_wp_error($response)) {
            $error_message = $response->get_error_message();
            // Handle the error
        } else {
            // Handle the response
        }
    }

    function my_custom_delete_post( $postid ){
        $data = array(
            'id' => $postid,
            'chatbot_id' => get_option('chatbot_id'),
        );
        $api_url = untrailingslashit(WPGPT_API_BASE_URL) . '/api/post_deleted/';
        $response = wp_remote_post($api_url, array(
            'method' => 'POST',
            'headers' => array(
                'Content-Type' => 'application/json; charset=utf-8',
            ),
            'body' => json_encode($data),
        ));
        if (is_wp_error($response)) {
            $error_message = $response->get_error_message();
            // Handle the error
        } else {
            // Handle the response
        }
    }

    function my_untrash_post( $postid ){
        $this->my_custom_save_post($postid, get_post($postid), true);
    }
}



new MyChatbotPlugin();
